@@ -62,6 +62,7 @@ cache.read = read
 
 var npm = require("./npm.js")
   , fs = require("graceful-fs")
+  , writeFileAtomic = require("write-file-atomic")
   , assert = require("assert")
   , rm = require("./utils/gently-rm.js")
   , readJson = require("read-package-json")
@@ -346,25 +347,15 @@ function afterAdd (cb) { return function (er, data) {
   var name = data.name
   var ver = data.version
   var pj = path.join(npm.cache, name, ver, "package", "package.json")
-  var tmp = pj + "." + process.pid
 
   var done = inflight(pj, cb)
 
   if (!done) return undefined
 
-  fs.writeFile(tmp, JSON.stringify(data), "utf8", function (er) {
+  getStat(function (er, cs) {
     if (er) return done(er)
-    getStat(function (er, cs) {
-      if (er) return done(er)
-      fs.rename(tmp, pj, function (er) {
-        if (cs.uid && cs.gid) {
-          fs.chown(pj, cs.uid, cs.gid, function (er) {
-            return done(er, data)
-          })
-        } else {
-          done(er, data)
-        }
-      })
+    writeFileAtomic(pj, JSON.stringify(data), {chown : cs}, function (er) {
+      return done(er, data)
     })
   })
 }}
