@@ -1,6 +1,7 @@
 var mkdir = require("mkdirp")
   , assert = require("assert")
   , fs = require("graceful-fs")
+  , writeFileAtomic = require("write-file-atomic")
   , readJson = require("read-package-json")
   , log = require("npmlog")
   , path = require("path")
@@ -15,6 +16,7 @@ var mkdir = require("mkdirp")
   , chownr = require("chownr")
   , inflight = require("inflight")
   , once = require("once")
+  , writeStream = require('fs-write-stream-atomic')
 
 module.exports = addLocalTarball
 
@@ -58,7 +60,7 @@ function addLocalTarball (p, pkgData, shasum, cb_) {
   mkdir(path.dirname(tmp), function (er) {
     if (er) return cb(er)
     var from = fs.createReadStream(p)
-      , to = fs.createWriteStream(tmp)
+      , to = writeStream(tmp, { mode: npm.modes.file })
       , errState = null
     function errHandler (er) {
       if (errState) return
@@ -68,11 +70,7 @@ function addLocalTarball (p, pkgData, shasum, cb_) {
     to.on("error", errHandler)
     to.on("close", function () {
       if (errState) return
-      log.verbose("chmod", tmp, npm.modes.file.toString(8))
-      fs.chmod(tmp, npm.modes.file, function (er) {
-        if (er) return cb(er)
-        addTmpTarball(tmp, pkgData, shasum, cb)
-      })
+      addTmpTarball(tmp, pkgData, shasum, cb)
     })
     from.pipe(to)
   })
@@ -118,7 +116,7 @@ function addPlacedTarball_ (p, pkgData, uid, gid, resolvedSum, cb) {
       if (er) return cb(er)
       var pj = path.join(folder, "package.json")
       var json = JSON.stringify(pkgData, null, 2)
-      fs.writeFile(pj, json, "utf8", function (er) {
+      writeFileAtomic(pj, json, function (er) {
         cb(er, pkgData)
       })
     })
@@ -202,7 +200,7 @@ function addTmpTarball_ (tgz, data, shasum, cb) {
 
       if (er) return cb(er)
       var read = fs.createReadStream(tgz)
-      var write = fs.createWriteStream(target)
+      var write = writeStream(target, { mode: npm.modes.file })
       var fin = cs.uid && cs.gid ? chown : done
       read.on("error", cb).pipe(write).on("error", cb).on("close", fin)
     })
