@@ -17,6 +17,7 @@ var mkdir = require("mkdirp")
   , unlock = locker.unlock
   , getCacheStat = require("./get-stat.js")
   , addLocalTarball = require("./add-local-tarball.js")
+  , writeStream = require('fs-write-stream-atomic')
 
 
 // 1. cacheDir = path.join(cache,'_git-remotes',sha1(u))
@@ -205,7 +206,7 @@ function archiveGitRemote (p, u, co, origUrl, cb) {
       if (er) return cb(er)
       var gzip = zlib.createGzip({ level: 9 })
       var args = ["archive", co, "--format=tar", "--prefix=package/"]
-      var out = fs.createWriteStream(tmp)
+      var out = writeStream(tmp)
       var env = gitEnv()
       cb = once(cb)
       var cp = git.spawn(args, { env: env, cwd: p })
@@ -261,11 +262,11 @@ function addModeRecursive(p, mode, cb) {
 }
 
 function addMode(p, mode, cb) {
-    fs.stat(p, function (er, stats) {
-      if (er) return cb(er)
-      mode = stats.mode | mode
-      fs.chmod(p, mode, cb)
-    })
+  fs.stat(p, function (er, stats) {
+    if (er) return cb(er)
+    mode = stats.mode | mode
+    fs.chmod(p, mode, cb)
+  })
 }
 
 // taken from https://github.com/isaacs/chmodr/blob/master/chmodr.js
