@@ -73,6 +73,7 @@ var npm = require("./npm.js")
   , log = require("npmlog")
   , path = require("path")
   , fs = require("graceful-fs")
+  , writeFileAtomic = require("write-file-atomic")
   , cache = require("./cache.js")
   , asyncMap = require("slide").asyncMap
   , chain = require("slide").chain
@@ -163,7 +164,7 @@ function install (args, cb_) {
           target = dep + "@" + target
           return target
         }), where, context, function(er, results) {
-          if (er) return cb(er, results)
+          if (er || npm.config.get("production")) return cb(er, results)
           lifecycle(data, "prepublish", where, function(er) {
             return cb(er, results)
           })
@@ -420,7 +421,7 @@ function save (where, installed, tree, pretty, hasArguments, cb) {
       data[deps] = sortedObject(data[deps])
 
       data = JSON.stringify(data, null, 2) + "\n"
-      fs.writeFile(saveTarget, data, function (er) {
+      writeFileAtomic(saveTarget, data, function (er) {
         cb(er, installed, tree, pretty)
       })
     })
