@@ -38,22 +38,14 @@ npm.config = {
 
 npm.commands = {}
 
+npm.rollbacks = []
+
 try {
   var pv = process.version.replace(/^v/, '')
   // startup, ok to do this synchronously
   var j = JSON.parse(fs.readFileSync(
     path.join(__dirname, "../package.json"))+"")
   npm.version = j.version
-  npm.nodeVersionRequired = j.engines.node
-  if (!semver.satisfies(pv, j.engines.node)) {
-    log.warn("unsupported version", [""
-            ,"npm requires node version: "+j.engines.node
-            ,"And you have: "+pv
-            ,"which is not satisfactory."
-            ,""
-            ,"Bad things will likely happen.  You have been warned."
-            ,""].join("\n"))
-  }
 } catch (ex) {
   try {
     log.info("error reading version", ex)
@@ -151,6 +143,7 @@ var commandCache = {}
               ]
   , plumbing = [ "build"
                , "unbuild"
+               , "isntall"
                , "xmas"
                , "substack"
                , "visnup"
@@ -311,6 +304,18 @@ function load (npm, cli, cb) {
       npm.config = config
       if (er) return cb(er)
 
+      // if the "project" config is not a filename, and we're
+      // not in global mode, then that means that it collided
+      // with either the default or effective userland config
+      if (!config.get("global")
+          && config.sources.project
+          && config.sources.project.type !== "ini") {
+        log.verbose("config"
+                   , "Skipping project config: %s. "
+                   + "(matches userconfig)"
+                   , config.localPrefix + "/.npmrc")
+      }
+
       // Include npm-version and node-version in user-agent
       var ua = config.get("user-agent") || ""
       ua = ua.replace(/\{node-version\}/gi, process.version)
@@ -324,20 +329,14 @@ function load (npm, cli, cb) {
       log.level = config.get("loglevel")
       log.heading = config.get("heading") || "npm"
       log.stream = config.get("logstream")
-      switch (color) {
-        case "always": log.enableColor(); break
-        case false: log.disableColor(); break
-      }
-      log.resume()
 
-      if (er) return cb(er)
-
-      // see if we need to color normal output
       switch (color) {
         case "always":
+          log.enableColor()
           npm.color = true
           break
         case false:
+          log.disableColor()
           npm.color = false
           break
         default:
@@ -349,6 +348,8 @@ function load (npm, cli, cb) {
           break
       }
 
+      log.resume()
+
       // at this point the configs are all set.
       // go ahead and spin up the registry client.
       npm.registry = new RegClient(npm.config)
@@ -364,7 +365,7 @@ function load (npm, cli, cb) {
       var lp = Object.getOwnPropertyDescriptor(config, "localPrefix")
       Object.defineProperty(npm, "localPrefix", lp)
 
-      return cb()
+      return cb(null, npm)
     })
   })
 }
