@@ -11,6 +11,7 @@ var cbCalled = false
   , exitCode = 0
   , rollbacks = npm.rollbacks
   , chain = require("slide").chain
+  , writeStream = require('fs-write-stream-atomic')
 
 
 process.on("exit", function (code) {
@@ -352,7 +353,7 @@ function writeLogFile (cb) {
   wroteLogFile = true
 
   var fs = require("graceful-fs")
-    , fstr = fs.createWriteStream("npm-debug.log")
+    , fstr = writeStream("npm-debug.log")
     , os = require("os")
     , out = ""
 
